"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = __importDefault(require("fs-extra"));
const command_1 = require("@salesforce/command");
const rimraf = require("rimraf");
const core_1 = require("@salesforce/core");
const getPackageInfo_1 = require("../../../../shared/getPackageInfo");
const searchFilesInDirectory_1 = require("../../../../shared/searchFilesInDirectory");
const diffutils_1 = __importDefault(require("../../../../shared/diffutils"));
const zipDirectory_1 = require("../../../../shared/zipDirectory");
var path = require('path');
const spawn = require('child-process-promise').spawn;
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfpowerkit', 'source_permissionset_generatepatch');
class Generatepatch extends command_1.SfdxCommand {
    async run() {
        //clean any existing temp sf powerkit source folder
        rimraf.sync('temp_sfpowerkit');
        // Getting Project config
        const project = await core_1.SfdxProject.resolve();
        const projectJson = await project.retrieveSfdxProjectJson();
        //Retrieve the package
        let packageToBeUsed;
        if (this.flags.package)
            packageToBeUsed = getPackageInfo_1.getPackageInfo(projectJson, this.flags.package);
        else {
            packageToBeUsed = getPackageInfo_1.getDefaultPackageInfo(projectJson);
        }
        //set permset directory
        let permsetDirPath;
        if (this.flags.permsetdir)
            permsetDirPath = this.flags.permsetdir;
        else {
            permsetDirPath = packageToBeUsed.path + `/main/default/permissionsets/`;
        }
        this.ux.log("Scanning for Permissionsets");
        let permissionsetList = searchFilesInDirectory_1.searchFilesInDirectory(permsetDirPath, '</PermissionSet>', '.xml');
        if (permissionsetList && permissionsetList.length > 0) {
            this.ux.log("Found " + `${permissionsetList.length}` + " Permissionsets");
            let diffUtils = new diffutils_1.default('0', '0');
            fs_extra_1.default.mkdirSync('temp_sfpowerkit');
            permissionsetList.forEach(file => {
                diffUtils.copyFile(file, 'temp_sfpowerkit');
            });
            var sfdx_project_json = `{
        "packageDirectories": [
          {
            "path": "${packageToBeUsed.path}",
            "default": true
          }
        ],
        "namespace": "",
        "sourceApiVersion": "46.0"
      }`;
            fs_extra_1.default.outputFileSync('temp_sfpowerkit/sfdx-project.json', sfdx_project_json);
            //Convert to mdapi
            const args = [];
            args.push('force:source:convert');
            args.push('-r');
            args.push(`${packageToBeUsed.path}`);
            args.push('-d');
            args.push(`mdapi`);
            await spawn('sfdx', args, {
                stdio: 'inherit',
                cwd: 'temp_sfpowerkit'
            });
            //Generate zip file
            var zipFile = 'temp_sfpowerkit/' + `${packageToBeUsed.package}` + '_permissionsets.zip';
            await zipDirectory_1.zipDirectory('temp_sfpowerkit/mdapi', zipFile);
            //Create Static Resource Directory if not exist
            let dir = packageToBeUsed.path + `/main/default/staticresources/`;
            if (!fs_extra_1.default.existsSync(dir)) {
                fs_extra_1.default.mkdirSync(dir);
            }
            fs_extra_1.default.copyFileSync(zipFile, packageToBeUsed.path + `/main/default/staticresources/${packageToBeUsed.package}_permissionsets.zip`);
            //Store it to static resources
            var metadata = `<?xml version="1.0" encoding="UTF-8"?>
      <StaticResource xmlns="http://soap.sforce.com/2006/04/metadata">
          <cacheControl>Public</cacheControl>
          <contentType>application/zip</contentType>
      </StaticResource>`;
            let targetmetadatapath = packageToBeUsed.path + `/main/default/staticresources/${packageToBeUsed.package}_permissionsets.resource-meta.xml`;
            this.ux.log("Generating static resource file : " + `${targetmetadatapath}`);
            fs_extra_1.default.outputFileSync(targetmetadatapath, metadata);
            this.ux.log(`Patch ${packageToBeUsed.package}_permissionsets generated successfully.`);
            //clean temp sf powerkit source folder
            rimraf.sync('temp_sfpowerkit');
        }
        else {
            this.ux.log("No permissionsets found");
        }
        return 0;
    }
}
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Generatepatch.requiresProject = true;
Generatepatch.description = messages.getMessage('commandDescription');
Generatepatch.examples = [
    `$ sfdx sfpowerkit:source:permissionset:generatepatch -p Core -d src/core/main/default/permissionsets
     Scanning for permissionsets
     Found 30 permissionsets
     Source was successfully converted to Metadata API format and written to the location: .../temp_sfpowerkit/mdapi
     Generating static resource file : src/core/main/default/staticresources/Core_permissionsets.resource-meta.xml
     Patch Core_permissionsets generated successfully.
  `
];
Generatepatch.flagsConfig = {
    package: command_1.flags.string({ required: false, char: 'p', description: messages.getMessage('packageFlagDescription') }),
    permsetdir: command_1.flags.string({ required: false, char: 'd', description: messages.getMessage('permsetDirFlagDescription') }),
};
exports.default = Generatepatch;
//# sourceMappingURL=generatepatch.js.map